"""
Resource documentation can be found <a href='/docs/api/core/default/resources/simple'>here</a>
"""

from . import simple

__all__ = ["simple"]
